==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/de_DE.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Abrufen des Anfrage-Tokens fehlgeschlagen. Stellen Sie sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Abrufen des Zugriff-Tokens fehlgeschlagen. Stellen Sie sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Please provide a valid app key and secret." : "Bitte tragen Sie einen gültigen App-Key mit Secret ein.",
    "Step 1 failed. Exception: %s" : "Schritt 1 fehlgeschlagen. Fehlermeldung: %s",
    "Step 2 failed. Exception: %s" : "Schritt 2 fehlgeschlagen. Fehlermeldung: %s",
    "External storage" : "Externer Speicher",
    "Storage with id \"%i\" not found" : "Der Speicher mit der ID „%i“ wurde nicht gefunden",
    "Invalid backend or authentication mechanism class" : "Ungültiges Backend oder falscher Authentifizierungsmodus",
    "Invalid mount point" : "Ungültiger mount point",
    "Objectstore forbidden" : "Objekt nicht erlaubt",
    "Invalid storage backend \"%s\"" : "Ungültiges Speicher-Backend „%s“",
    "Not permitted to use backend \"%s\"" : "Es ist nicht zulässig Backend \"%s\" zu verwenden",
    "Unsatisfied backend parameters" : "Unbefriedigende Backend-Parameter",
    "Insufficient data: %s" : "Unzureichende Daten: %s",
    "%s" : "%s",
    "Personal" : "Persönlich",
    "System" : "System",
    "Grant access" : "Zugriff gestatten",
    "Access granted" : "Zugriff gestattet",
    "Error configuring OAuth1" : "Fehler beim Konfigurieren von OAuth1",
    "Generate keys" : "Schlüssel erzeugen",
    "Error generating key pair" : "Fehler beim Erzeugen des Schlüsselpaares",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "Enable previews" : "Vorschau aktivieren",
    "Enable sharing" : "Teilen aktivieren",
    "Check for changes" : "Auf Änderungen überprüfen",
    "Never" : "Nie",
    "Once every direct access" : "Einmal bei jedem Direktzugriff",
    "All users. Type to select user or group." : "Alle Benutzer. Benutzer oder Gruppe zur Auswahl eingeben.",
    "(group)" : "(group)",
    "Saved" : "Gespeichert",
    "Empty response from the server" : "Leere Antwort vom Server erhalten",
    "External mount error" : "Externer Einhängefehler",
    "external-storage" : "externer Speicher",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Save" : "Speichern",
    "Access key" : "Zugangsschlüssel",
    "Secret key" : "geheimer Schlüssel",
    "Builtin" : "Builtin",
    "None" : "Keine",
    "OAuth1" : "OAuth1",
    "App key" : "App-Schlüssel",
    "App secret" : "Geheime Zeichenkette der App",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client-ID",
    "Client secret" : "Geheime Zeichenkette des Client",
    "OpenStack" : "Freihand",
    "Tenant name" : "Name des Mieters",
    "Rackspace" : "Rackspace",
    "API key" : "API-Schlüssel",
    "Username and password" : "Benutzername und Passwort",
    "Public key" : "Öffentlicher Schlüssel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Host-Name",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "SSL aktivieren",
    "Enable Path Style" : "Pfadstil aktivieren",
    "WebDAV" : "WebDAV",
    "URL" : "Adresse",
    "Remote subfolder" : "Entfernter Unterordner",
    "Secure https://" : "Sicheres https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Sicheres ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Ort",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP mit dem Login über einen geheimen Schlüssel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS mit OC-Login",
    "Username as share" : "Benutzername als Freigabe",
    "OpenStack Object Storage" : "Openstack-Objektspeicher",
    "Service name" : "Dienst Name",
    "<b>Note:</b> " : "<b>Hinweis:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> Die cURL-Unterstützung von PHP ist nicht aktiviert oder installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wenden Sie sich zur Installation an Ihren Systemadministrator.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> Die FTP Unterstützung von PHP ist nicht aktiviert oder installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wenden Sie sich zur Installation an Ihren Systemadministrator.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> \"%s\" ist nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wenden Sie sich zur Installation an Ihren Systemadministrator.",
    "No external storage configured" : "Kein externer Speicher konfiguriert",
    "You can add external storages in the personal settings" : "Sie können externe Speicher in den persönlichen Einstellungen hinzufügen",
    "Name" : "Name",
    "Storage type" : "Speichertyp",
    "Scope" : "Anwendungsbereich",
    "External Storage" : "Externer Speicher",
    "Folder name" : "Ordnername",
    "Authentication" : "Authentifizierung",
    "Configuration" : "Konfiguration",
    "Available for" : "Verfügbar für",
    "Add storage" : "Speicher hinzufügen",
    "Advanced settings" : "Erweiterte Einstellungen",
    "Delete" : "Löschen",
    "Allow users to mount external storage" : "Erlauben Sie den Benutzern externen Speicher hinzuzufügen",
    "Allow users to mount the following external storage" : "Benutzern erlauben, den oder die folgenden externen Speicher einzubinden:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/de_DE.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Abrufen des Anfrage-Tokens fehlgeschlagen. Stellen Sie sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Abrufen des Zugriff-Tokens fehlgeschlagen. Stellen Sie sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Please provide a valid app key and secret." : "Bitte tragen Sie einen gültigen App-Key mit Secret ein.",
    "Step 1 failed. Exception: %s" : "Schritt 1 fehlgeschlagen. Fehlermeldung: %s",
    "Step 2 failed. Exception: %s" : "Schritt 2 fehlgeschlagen. Fehlermeldung: %s",
    "External storage" : "Externer Speicher",
    "Dropbox App Configuration" : "Dropbox-App Konfiguration",
    "Google Drive App Configuration" : "Google Drive - App Konfiguration",
    "Personal" : "Persönlich",
    "System" : "System",
    "Grant access" : "Zugriff gestatten",
    "Error configuring OAuth1" : "Fehler beim Konfigurieren von OAuth1",
    "Error configuring OAuth2" : "Fehler beim Konfigurieren von OAuth2",
    "Generate keys" : "Schlüssel erzeugen",
    "Error generating key pair" : "Fehler beim Erzeugen des Schlüsselpaares",
    "All users. Type to select user or group." : "Alle Benutzer. Benutzer oder Gruppe zur Auswahl eingeben.",
    "(group)" : "(group)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilität mit MAC NFD-Kodierung (langsam)",
    "Admin defined" : "Administrator definiert",
    "Saved" : "Gespeichert",
    "Empty response from the server" : "Leere Antwort vom Server erhalten",
    "Couldn't access. Please logout and login to activate this mount point" : "Anmeldung nicht möglich. Bitte melden Sie sich ab und wieder an, damit Sie von diesem Endpunkt zugreifen können.",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Es konnten keine Informationen aus dem ownCloud -Server gelesen werden: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Konnte die Liste von externen Speichern nicht laden: {type}",
    "There was an error with message: " : "Ein Fehler ist aufgetreten:",
    "External mount error" : "Externer Einhängefehler",
    "external-storage" : "externer Speicher",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Es konnte keine Liste der Windows-Netzlaufwerke erstellt werden: leer Antwort vom Server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Einige der konfigurierten externen Bereitstellungspunkte  sind nicht angeschlossen. Bitte klicke Sie auf die roten Zeile(n) für weitere Informationen",
    "Please enter the credentials for the {mount} mount" : "Bitte geben Sie die Zugangsdaten für den {mount} Speicher an",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Credentials saved" : "Zugangsdaten gespeichert",
    "Credentials saving failed" : "Speichern der Zugangsdaten fehlgeschlagen",
    "Credentials required" : "Zugangsdaten benötigt",
    "Save" : "Speichern",
    "Storage with id \"%i\" not found" : "Der Speicher mit der ID „%i“ wurde nicht gefunden",
    "Invalid backend or authentication mechanism class" : "Ungültiges Backend oder falscher Authentifizierungsmodus",
    "Invalid mount point" : "Ungültiger mount point",
    "Objectstore forbidden" : "Objekt nicht erlaubt",
    "Invalid storage backend \"%s\"" : "Ungültiges Speicher-Backend „%s“",
    "Not permitted to use backend \"%s\"" : "Es ist nicht zulässig Backend \"%s\" zu verwenden",
    "Not permitted to use authentication mechanism \"%s\"" : "Nicht erlaubter Autentifizierungsmechanismus \"%s\"",
    "Unsatisfied backend parameters" : "Unbefriedigende Backend-Parameter",
    "Unsatisfied authentication mechanism parameters" : "Unbefriedigende Autentifizierungs-Mechanismus Parameter",
    "Insufficient data: %s" : "Unzureichende Daten: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Der Speicher mit der ID „%i“ ist nicht bearbeitbar durch Benutzer",
    "Access key" : "Zugangsschlüssel",
    "Secret key" : "geheimer Schlüssel",
    "Builtin" : "Builtin",
    "None" : "Keine",
    "OAuth1" : "OAuth1",
    "App key" : "App-Schlüssel",
    "App secret" : "Geheime Zeichenkette der App",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client-ID",
    "Client secret" : "Geheime Zeichenkette des Client",
    "OpenStack" : "Freihand",
    "Tenant name" : "Name des Mieters",
    "Identity endpoint URL" : "Identität Endpunkt-URL",
    "Rackspace" : "Rackspace",
    "API key" : "API-Schlüssel",
    "Username and password" : "Benutzername und Passwort",
    "Log-in credentials, save in session" : "Anmelde-Zugangsdaten, speichere in Sitzung",
    "RSA public key" : "RSA öffentlicher Schlüssel",
    "Public key" : "Öffentlicher Schlüssel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Host-Name",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "SSL aktivieren",
    "Enable Path Style" : "Pfadstil aktivieren",
    "WebDAV" : "WebDAV",
    "URL" : "Adresse",
    "Remote subfolder" : "Entfernter Unterordner",
    "Secure https://" : "Sicheres https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Sicheres ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Ort",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP mit dem Login über einen geheimen Schlüssel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS mit OC-Login",
    "Username as share" : "Benutzername als Freigabe",
    "OpenStack Object Storage" : "Openstack-Objektspeicher",
    "Service name" : "Dienst Name",
    "Request timeout (seconds)" : "Anfrage-Zeitüberschreitung (Sekunden)",
    "<b>Note:</b> " : "<b>Hinweis:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> Die cURL-Unterstützung von PHP ist nicht aktiviert oder installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wenden Sie sich zur Installation an Ihren Systemadministrator.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> Die FTP Unterstützung von PHP ist nicht aktiviert oder installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wenden Sie sich zur Installation an Ihren Systemadministrator.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> \"%s\" ist nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wenden Sie sich zur Installation an Ihren Systemadministrator.",
    "No external storage configured" : "Kein externer Speicher konfiguriert",
    "You can add external storages in the personal settings" : "Sie können externe Speicher in den persönlichen Einstellungen hinzufügen",
    "Name" : "Name",
    "Storage type" : "Speichertyp",
    "Scope" : "Anwendungsbereich",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "Enable previews" : "Vorschau aktivieren",
    "Enable sharing" : "Teilen aktivieren",
    "Check for changes" : "Auf Änderungen überprüfen",
    "Never" : "Nie",
    "Once every direct access" : "Einmal bei jedem Direktzugriff",
    "External Storage" : "Externer Speicher",
    "Folder name" : "Ordnername",
    "Authentication" : "Authentifizierung",
    "Configuration" : "Konfiguration",
    "Available for" : "Verfügbar für",
    "Add storage" : "Speicher hinzufügen",
    "Advanced settings" : "Erweiterte Einstellungen",
    "Delete" : "Löschen",
    "Allow users to mount external storage" : "Erlauben Sie den Benutzern externen Speicher hinzuzufügen",
    "Allow users to mount the following external storage" : "Benutzern erlauben, den oder die folgenden externen Speicher einzubinden:"
},
"nplurals=2; plural=(n != 1);");
